==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/ForSystemInterfaceOnly.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INTERFACE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCECODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCESYSTEM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACCOUNTDETAIL" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_interface",
    "sourcecode",
    "sourcesystem",
    "accountdetail"
})
@XmlRootElement(name = "ForSystemInterfaceOnly")
public class ForSystemInterfaceOnly {

    @XmlElement(name = "INTERFACE")
    protected DATETIME _interface;
    @XmlElement(name = "SOURCECODE")
    protected String sourcecode;
    @XmlElement(name = "SOURCESYSTEM")
    protected String sourcesystem;
    @XmlElement(name = "ACCOUNTDETAIL")
    protected QUANTITY accountdetail;

    /**
     * Gets the value of the interface property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getINTERFACE() {
        return _interface;
    }

    /**
     * Sets the value of the interface property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setINTERFACE(DATETIME value) {
        this._interface = value;
    }

    /**
     * Gets the value of the sourcecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSOURCECODE() {
        return sourcecode;
    }

    /**
     * Sets the value of the sourcecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSOURCECODE(String value) {
        this.sourcecode = value;
    }

    /**
     * Gets the value of the sourcesystem property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSOURCESYSTEM() {
        return sourcesystem;
    }

    /**
     * Sets the value of the sourcesystem property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSOURCESYSTEM(String value) {
        this.sourcesystem = value;
    }

    /**
     * Gets the value of the accountdetail property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getACCOUNTDETAIL() {
        return accountdetail;
    }

    /**
     * Sets the value of the accountdetail property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setACCOUNTDETAIL(QUANTITY value) {
        this.accountdetail = value;
    }

}

==> eam-wshub-proxyclient-11.4-10-sources.jar: net/datastream/schemas/mp_fields/ForSystemInterfaceOnly.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INTERFACE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCECODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCESYSTEM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACCOUNTDETAIL" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_interface",
    "sourcecode",
    "sourcesystem",
    "accountdetail"
})
@XmlRootElement(name = "ForSystemInterfaceOnly")
public class ForSystemInterfaceOnly {

    @XmlElement(name = "INTERFACE")
    protected DATETIME _interface;
    @XmlElement(name = "SOURCECODE")
    protected String sourcecode;
    @XmlElement(name = "SOURCESYSTEM")
    protected String sourcesystem;
    @XmlElement(name = "ACCOUNTDETAIL")
    protected QUANTITY accountdetail;

    /**
     * Obtient la valeur de la propriété interface.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getINTERFACE() {
        return _interface;
    }

    /**
     * Définit la valeur de la propriété interface.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setINTERFACE(DATETIME value) {
        this._interface = value;
    }

    /**
     * Obtient la valeur de la propriété sourcecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSOURCECODE() {
        return sourcecode;
    }

    /**
     * Définit la valeur de la propriété sourcecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSOURCECODE(String value) {
        this.sourcecode = value;
    }

    /**
     * Obtient la valeur de la propriété sourcesystem.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSOURCESYSTEM() {
        return sourcesystem;
    }

    /**
     * Définit la valeur de la propriété sourcesystem.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSOURCESYSTEM(String value) {
        this.sourcesystem = value;
    }

    /**
     * Obtient la valeur de la propriété accountdetail.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getACCOUNTDETAIL() {
        return accountdetail;
    }

    /**
     * Définit la valeur de la propriété accountdetail.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setACCOUNTDETAIL(QUANTITY value) {
        this.accountdetail = value;
    }

}
